Method: CDK::FSELECT#saveFocus
- Defined in:
- lib/cdk/components/fselect.rb
#saveFocus ⇒ Object
The fselect’s focus resides in the entry widget. But the scroll widget will not draw items highlighted unless it has focus. Temporarily adjust the focus of the scroll widget when drawing on it to get the right highlighting.
419 420 421 422 |
# File 'lib/cdk/components/fselect.rb', line 419 def saveFocus @save = @scroll_field.has_focus @scroll_field.has_focus = @entry_field.has_focus end |